@@ -3,16 +3,7 @@ import socket
 import sys
 import threading
 
-'''
-from src.gameboard.Board import Board
-from src.client.Client import Client
-from src.gameboard.NodeRoads import *
-from src.gameboard.Board import *
-from src.client.Client import *
-from src.client.Player import *
-
-'''
-sys.path.insert(0, '../src')
+sys.path.insert(0, '../frontiersman')
 from gameboard.Board import *
 from client.Gui import *
 from client.Player import *
@@ -47,9 +38,11 @@ class client:
 
     def board_thread(self, board):
         self.client_instance.run(board)
+
     @staticmethod
     def main(address='127.0.0.1', port=1233, name='Zander', num_players=2):
         client(address, int(port), name, int(num_players))
+
     def __init__(self, host_ip, port_ip, player_name='John', num_players=2):
         board_input = queue.Queue()
         board = Board()
@@ -69,7 +62,7 @@ class client:
             Response = self.read_from_buffer(ClientSocket)
             # print(Response)
             if Response == 'host':
-                #num_players = self.get_valid_player_input("How many players(including you)? ")  # add error checking from pakuri here
+                # num_players = self.get_valid_player_input("How many players(including you)? ")  # add error checking from pakuri here
                 ClientSocket.send(str.encode(str(num_players) + '\n'))
             elif Response == "quit":
                 break
@@ -137,7 +130,7 @@ class client:
                 board.generate_land(number_list, resource_list)
                 board.generate_ports(port_list)
                 self.client_instance.enemy_list = enemy_list
-                self.client_instance.board_updated=True
+                self.client_instance.board_updated = True
                 threading.Thread(target=self.board_thread, args=(board,)).start()
             elif Response == "getstart":
                 print("get starting resources")
@@ -169,7 +162,7 @@ class client:
                                                                                  int(message.split(',')[2]), Color)
                         self.client_instance.road_list.append(road)
                         self.client_instance.player.acquireRoad(road)
-                        self.client_instance.player.getLongestRoad(max([int(en.longestRoad) for en in self.client_instance.enemy_list],default=0))
+                        self.client_instance.player.getLongestRoad(max([int(en.longestRoad) for en in self.client_instance.enemy_list], default=0))
                         self.client_instance.set_board_updated(True)
                         self.client_instance.pay_cards([1, 0, 1, 0, 0])
                         ClientSocket.send(str.encode(message + ',' + Color + '\n'))
@@ -177,7 +170,7 @@ class client:
                     if (message.split(',')[0] == "robber"):
                         self.client_instance.game_board.set_robber(
                             (int(message.split(',')[1]), int(message.split(',')[2])))
-                        self.client_instance.player.getLargestArmy(max([int(en.largestArmy) for en in self.client_instance.enemy_list],default=0))
+                        self.client_instance.player.getLargestArmy(max([int(en.largestArmy) for en in self.client_instance.enemy_list], default=0))
                         self.client_instance.set_board_updated(True)
                         ClientSocket.send(str.encode(message + '\n'))
                         ClientSocket.send(str.encode("enemyu," + self.client_instance.player.getSendToEnemies() + '\n'))
@@ -238,7 +231,7 @@ class client:
                                                                                      int(message.split(',')[2]), Color)
                             self.client_instance.road_list.append(road)
                             self.client_instance.player.acquireRoad(road)
-                            self.client_instance.player.getLongestRoad(max([int(en.longestRoad) for en in self.client_instance.enemy_list],default=0))
+                            self.client_instance.player.getLongestRoad(max([int(en.longestRoad) for en in self.client_instance.enemy_list], default=0))
                             self.client_instance.set_board_updated(True)
                             ClientSocket.send(str.encode(message + ',' + Color + '\n'))
                             ClientSocket.send(
@@ -251,7 +244,7 @@ class client:
                                                                                      int(message.split(',')[2]), Color)
                             self.client_instance.road_list.append(road)
                             self.client_instance.player.acquireRoad(road)
-                            self.client_instance.player.getLongestRoad(max([int(en.longestRoad) for en in self.client_instance.enemy_list],default=0))
+                            self.client_instance.player.getLongestRoad(max([int(en.longestRoad) for en in self.client_instance.enemy_list], default=0))
                             self.client_instance.set_board_updated(True)
                             ClientSocket.send(str.encode(message + ',' + Color + '\n'))
                             ClientSocket.send(
@@ -298,16 +291,16 @@ if __name__ == "__main__":
     port = 1233
     xy = ''
     Name = "Name"
-    players=2
-    host=sys.argv[1]
+    players = 2
+    host = sys.argv[1]
     try:
-        port=int(sys.argv[2])
+        port = int(sys.argv[2])
     except(ValueError):
         print("port must be an int")
-    Name=sys.argv[3]
-    if(len(sys.argv)==5):
+    Name = sys.argv[3]
+    if (len(sys.argv) == 5):
         try:
-            players=int(sys.argv[4])
+            players = int(sys.argv[4])
         except(ValueError):
             print("number of players must be an int")
         test = client(host, port, Name, players)
