@@ -8,7 +8,7 @@ import sys
 import pygame.gfxdraw
 import pygame_gui as pg_g
 
-sys.path.insert(0, '../src')
+sys.path.insert(0, '../frontiersman')
 from gameboard.NodeRoads import *
 from gameboard.SettlementButtons import *
 from client.Bank import *
@@ -861,7 +861,7 @@ class Client:
         self.game_window = pygame.display.set_mode(RESOLUTION, pygame.FULLSCREEN)
         # self.game_window = pygame.display.set_mode(RESOLUTION)
 
-        self.manager = pg_g.UIManager(RESOLUTION, 'themes/card_theme.json')
+        self.manager = pg_g.UIManager(RESOLUTION, 'frontiersman/themes/card_theme.json')
         self.clock = pygame.time.Clock()
 
         # creates settlement polygon
